@@ -179,22 +179,15 @@ class Stream(object):
 
             data = data[num_bytes:]
 
-        safe_call(callback)
+        self._run_callback(callback)
 
     def closed(self):
         return not self.sock
 
     def reading(self):
-        """
-        永远是reading的状态
-        """
         return bool(self.reader_count)
 
     def writing(self):
-        """
-        不太好实现，就统一用False吧
-        对于短链接可能会有点影响
-        """
         return bool(self.writer_count)
 
     def set_nodelay(self, value):
@@ -216,7 +209,7 @@ class Stream(object):
         """
         替换为kola的safe_call
         """
-        safe_call(callback, *args)
+        return safe_call(callback, *args)
 
     def _set_read_callback(self, callback):
         assert not self._read_callback, "Already reading"
@@ -249,7 +242,7 @@ class Stream(object):
                                    self._consume(self._read_buffer_size))
 
             if self._close_callback:
-                safe_call(self._close_callback)
+                self._run_callback(self._close_callback)
                 self._close_callback = None
 
             # 直接返回，因为buffer里面一定没数据了
